@@ -5,13 +5,20 @@ use strict;
 use CGI::Carp 'fatalsToBrowser';
 use HTML::Perlinfo::Common;
 
-use App::Info::HTTPD::Apache;
-my $apache = App::Info::HTTPD::Apache->new();
+my ($apache,$appInstalled);
+eval{require App::Info::HTTPD::Apache};
+unless ($@) {
+	
+	use App::Info::HTTPD::Apache;
+	$apache = App::Info::HTTPD::Apache->new();
+	$appInstalled++;
+}
+
 
 sub new {
     my %apache;
     my $env  = ( $ENV{SERVER_SOFTWARE} || "" ) =~ /apache/i;
-    my $info = App::Info::HTTPD::Apache->new()->installed;
+    my $info = $appInstalled ? App::Info::HTTPD::Apache->new()->installed : 0;
     my $mp   = exists $ENV{MOD_PERL};
     $apache{'env'}  = $env;
     $apache{'info'} = $info;
@@ -46,7 +53,9 @@ sub print_apache {
 	
 	  ($version) = $ENV{'SERVER_SOFTWARE'} =~ /(\d+[\.\d]*)/ 
 				if (defined $ENV{'SERVER_SOFTWARE'} && $ENV{'SERVER_SOFTWARE'} =~ /\d+[\.\d]*/); 
-	}  
+	} 
+
+no warnings "all";
 	return join '', print_table_row(2, "Apache Version", "$version"),
                         (defined($ENV{'SERVER_NAME'}) && defined($ENV{'SERVER_PORT'})) ?
 			print_table_row(2, "Hostname:Port", "$ENV{'SERVER_NAME'} : $ENV{'SERVER_PORT'}"):
@@ -74,9 +83,7 @@ sub print_modperl {
             }
 	  } 	
 	  
-         my $image =  check_images('http://i104.photobucket.com') ? add_link('apache') : '';
-	 #my $image =  add_link('apache');
-	 return join '', print_box_start(0), $image, 
+	 return join '', print_box_start(0),  
 		"Running under mod_perl version $version_status (version number: $version_number)",
 			 print_box_end(); 
 
@@ -84,33 +91,37 @@ sub print_modperl {
 
 sub print_apache_environment {
 
-	return join '', print_table_row(2, "DOCUMENT_ROOT", "$ENV{'DOCUMENT_ROOT'} "),
-			print_table_row(2, "HTTP_ACCEPT", "$ENV{'HTTP_ACCEPT'} "),
-			print_table_row(2, "HTTP_ACCEPT_CHARSET", "$ENV{'HTTP_ACCEPT_CHARSET'} "),
-			print_table_row(2, "HTTP_ACCEPT_ENCODING", "$ENV{'HTTP_ACCEPT_ENCODING'} "),
-			print_table_row(2, "HTTP_ACCEPT_LANGUAGE", "$ENV{'HTTP_ACCEPT_LANGUAGE'} "),
-			print_table_row(2, "HTTP_CONNECTION", "$ENV{'HTTP_CONNECTION'} "),
-			print_table_row(2, "HTTP_HOSTS", "$ENV{'HTTP_HOSTS'} "),
-			print_table_row(2, "HTTP_KEEP_ALIVE", "$ENV{'HTTP_KEEP_ALIVE'} "),
-			print_table_row(2, "HTTP_USER_AGENT", "$ENV{'HTTP_USER_AGENT'} "),
-			print_table_row(2, "PATH", "$ENV{'PATH'} "),
-			print_table_row(2, "REMOTE_ADDR", "$ENV{'REMOTE_ADDR'} "),
-			print_table_row(2, "REMOTE_HOST", "$ENV{'REMOTE_HOST'} "),
-			print_table_row(2, "REMOTE_PORT", "$ENV{'REMOTE_PORT'} "),
-			print_table_row(2, "SCRIPT_FILENAME", "$ENV{'SCRIPT_FILENAME'} "),
-			print_table_row(2, "SCRIPT_URI", "$ENV{'SCRIPT_URI'} "),
-			print_table_row(2, "SCRIPT_URL", "$ENV{'SCRIPT_URL'} "),
-			print_table_row(2, "SERVER_ADDR", "$ENV{'SERVER_ADDR'} "),
-			print_table_row(2, "SERVER_ADMIN", "$ENV{'SERVER_ADMIN'} "),
-			print_table_row(2, "SERVER_NAME", "$ENV{'SERVER_NAME'} "),
-			print_table_row(2, "SERVER_PORT", "$ENV{'SERVER_PORT'} "),
-			print_table_row(2, "SERVER_SIGNATURE", "$ENV{'SERVER_SIGNATURE'} "),
-			print_table_row(2, "SERVER_SOFTWARE", "$ENV{'SERVER_SOFTWARE'} "),
-			print_table_row(2, "GATEWAY_INTERFACE", "$ENV{'GATEWAY_INTERFACE'} "),
-			print_table_row(2, "SERVER_PROTOCOL", "$ENV{'SERVER_PROTOCOL'} "),
-			print_table_row(2, "REQUEST_METHOD", "$ENV{'REQUEST_METHOD'} "),
-			print_table_row(2, "QUERY_STRING", "$ENV{'QUERY_STRING'} "),
-			print_table_row(2, "REQUEST_URI", "$ENV{'REQUEST_URI'} "),
-			print_table_row(2, "SCRIPT_NAME", "$ENV{'SCRIPT_NAME'} ");  
+	no warnings "all";
+
+	return join '', print_table_row(2, "DOCUMENT_ROOT", $ENV{'DOCUMENT_ROOT'}),
+
+	print_table_row(2, "HTTP_ACCEPT", $ENV{'HTTP_ACCEPT'}),
+			print_table_row(2, "HTTP_ACCEPT_CHARSET", $ENV{'HTTP_ACCEPT_CHARSET'}),
+			print_table_row(2, "HTTP_ACCEPT_ENCODING", $ENV{'HTTP_ACCEPT_ENCODING'}),
+			print_table_row(2, "HTTP_ACCEPT_LANGUAGE", $ENV{'HTTP_ACCEPT_LANGUAGE'}),
+			print_table_row(2, "HTTP_CONNECTION", $ENV{'HTTP_CONNECTION'}),
+			print_table_row(2, "HTTP_HOSTS", $ENV{'HTTP_HOSTS'}),
+			print_table_row(2, "HTTP_KEEP_ALIVE", $ENV{'HTTP_KEEP_ALIVE'}),
+			print_table_row(2, "HTTP_USER_AGENT", $ENV{'HTTP_USER_AGENT'}),
+			print_table_row(2, "PATH", $ENV{'PATH'}),
+			print_table_row(2, "REMOTE_ADDR", $ENV{'REMOTE_ADDR'}),
+			print_table_row(2, "REMOTE_HOST", $ENV{'REMOTE_HOST'}),
+			print_table_row(2, "REMOTE_PORT", $ENV{'REMOTE_PORT'}),
+			print_table_row(2, "SCRIPT_FILENAME", $ENV{'SCRIPT_FILENAME'}),
+			print_table_row(2, "SCRIPT_URI", $ENV{'SCRIPT_URI'}),
+			print_table_row(2, "SCRIPT_URL", $ENV{'SCRIPT_URL'}),
+			print_table_row(2, "SERVER_ADDR", $ENV{'SERVER_ADDR'}),
+			print_table_row(2, "SERVER_ADMIN", $ENV{'SERVER_ADMIN'}),
+			print_table_row(2, "SERVER_NAME", $ENV{'SERVER_NAME'}),
+			print_table_row(2, "SERVER_PORT", $ENV{'SERVER_PORT'}),
+			print_table_row(2, "SERVER_SIGNATURE", $ENV{'SERVER_SIGNATURE'}),
+			print_table_row(2, "SERVER_SOFTWARE", $ENV{'SERVER_SOFTWARE'}),
+			print_table_row(2, "GATEWAY_INTERFACE", $ENV{'GATEWAY_INTERFACE'}),
+			print_table_row(2, "SERVER_PROTOCOL", $ENV{'SERVER_PROTOCOL'}),
+			print_table_row(2, "REQUEST_METHOD", $ENV{'REQUEST_METHOD'}),
+			print_table_row(2, "QUERY_STRING", $ENV{'QUERY_STRING'}),
+			print_table_row(2, "REQUEST_URI", $ENV{'REQUEST_URI'}),
+			print_table_row(2, "SCRIPT_NAME", $ENV{'SCRIPT_NAME'});  
+
 }
 1;
